==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/older.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR);   
$VAR['Content'] = "";
$VAR['Display'] =& $align;
if (ereg("(stories|index).php",$_SERVER['PHP_SELF']) && empty($story) && (empty($page) || $page==1)) {
	$sql = "SELECT * FROM T_Stories ";
	$sql .= "WHERE Verified = 'Y' ORDER BY Repostamp desc ";
	$sql .= sprintf("LIMIT %s,%s",$CONF["LimitNews"],$CONF["LimitNews"]); 
	$older_result = SqlQuery($sql);
	$older_nrows = mysql_num_rows($older_result);
	$cnt	= $cnt	+ $older_nrows;	

	if ($CONF['Older']>0 && $older_nrows>0) {
		$VAR['Heading']	= _OLDER;
		$D = "noday";
		$VAR['Content'] = "";
		while ($A = mysql_fetch_array($older_result)) {
			if ($CONF['DAYOFWEEK'] && $D != KWL_DateFormat($A['Repostamp'],"%A %b/%d")) {
				$D	= KWL_DateFormat($A['Repostamp'],"%A %b/%d");
				$VAR['Content']	.= "<b>" . $D . "</b><br />\n";
			}
		$VAR['Content']	.= "$CONF[dotchar]<a href=\"" . KWL_MakeStoryLink($A['Rid']) . "\">". KWL_StringCut($A['Heading'],25,true) ."</a> ($A[replys])<br />\n";
		}
		KWL_DrawBlock($VAR);
		mysql_free_result($older_result);
	}
} else {
	$sql = "SELECT * FROM T_Stories ";
	$sql .= "WHERE Verified = 'Y' ORDER BY Repostamp desc ";
	$sql .= sprintf("LIMIT %s",$CONF["LimitNews"]); 
	$older_result = SqlQuery($sql);
	$older_nrows = mysql_num_rows($older_result);
	$cnt	= $cnt	+ $older_nrows;	
	if ($CONF['Older']>0 && $older_nrows>0) {
		$VAR['Heading']	= _LAST_STORY;
		$D = "noday";
		while ($A = mysql_fetch_array($older_result)) {
			if ($CONF['DAYOFWEEK'] && $D != KWL_DateFormat($A['Repostamp'],"%A %b/%d")) {
				$D	= KWL_DateFormat($A['Repostamp'],"%A %b/%d");
				$VAR['Content']	.= "<b>" . $D . "</b><br />\n";
			}
		$VAR['Content']	.= "$CONF[dotchar]<a href=\"" . KWL_MakeStoryLink($A['Rid']) . "\">". KWL_StringCut($A['Heading'],25,true) ."</a> ($A[replys])<br />\n";
		}
		KWL_DrawBlock($VAR);
		mysql_free_result($older_result);
	}
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/include/sblock/older.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR);   
$VAR['Content'] = "";
$VAR['Display'] =& $align;
if (ereg("(stories|index).php",$_SERVER['PHP_SELF']) && empty($story) && (empty($page) || $page==1)) {
	$sql = "SELECT * FROM T_Stories ";
	$sql .= "WHERE Verified = 'Y' ORDER BY Repostamp desc ";
	$sql .= sprintf("LIMIT %s,%s",$CONF["LimitNews"],$CONF["LimitNews"]); 
	$older_result = SqlQuery($sql);
	$older_nrows = mysql_num_rows($older_result);
	$cnt	= $cnt	+ $older_nrows;	

	if ($CONF['Older']>0 && $older_nrows>0) {
		$VAR['Heading']	= _OLDER;
		$D = "noday";
		$VAR['Content'] = "";
		while ($A = mysql_fetch_array($older_result)) {
			if ($CONF['DAYOFWEEK'] && $D != KWL_DateFormat($A['Repostamp'],"%A %b/%d")) {
				$D	= KWL_DateFormat($A['Repostamp'],"%A %b/%d");
				$VAR['Content']	.= "<b>" . $D . "</b><br />\n";
			}
		$VAR['Content']	.= "{$CONF['dotchar']}<a href=\"" . KWL_MakeStoryLink($A['Rid']) . "\">{$A['Heading']}</a>({$A['replys']})<br />\n";
		}
		KWL_DrawBlock($VAR);
		mysql_free_result($older_result);
	}
} else {
	$sql = "SELECT * FROM T_Stories ";
	$sql .= "WHERE Verified = 'Y' ORDER BY Repostamp desc ";
	$sql .= sprintf("LIMIT %s",$CONF["LimitNews"]); 
	$older_result = SqlQuery($sql);
	$older_nrows = mysql_num_rows($older_result);
	$cnt	= $cnt	+ $older_nrows;	
	if ($CONF['Older']>0 && $older_nrows>0) {
		$VAR['Heading']	= _LAST_STORY;
		$D = "noday";
		while ($A = mysql_fetch_array($older_result)) {
			if ($CONF['DAYOFWEEK'] && $D != KWL_DateFormat($A['Repostamp'],"%A %b/%d")) {
				$D	= KWL_DateFormat($A['Repostamp'],"%A %b/%d");
				$VAR['Content']	.= "<b>" . $D . "</b><br />\n";
			}
		$VAR['Content']	.= "{$CONF['dotchar']}<a href=\"" . KWL_MakeStoryLink($A['Rid']) . "\">{$A['Heading']}</a>({$A['replys']})<br />\n";
		}
		KWL_DrawBlock($VAR);
		mysql_free_result($older_result);
	}
}
?>
